function l = split(s,delim)
% l = split(s,delim)
% splits a string s delimited by characters in delim.  Meant to
% work roughly like the PERL split function (but without any
% regular expression support).  Internally uses STRTOK to do 
% the splitting.  Returns a cell array of strings.
% If delim is omitted, default behavior of strtok() is inherited
% (blank, tab, and cr's).
%
% Example:
%    >> split('_/', 'this_is___a_/_string/_//')
%    ans = 
%        'this'    'is'    'a'    'string'
%
% based on Gerald Dalley (dalleyg@mit.edu), 2004
% a slight modification by dmochiha@slt.atr.jp, 2004
% $Id: split.m,v 1.3 2004/09/30 04:37:56 dmochiha Exp $
l = {};
s = deblank(s);
while (length(s) > 0)
  if nargin < 2
    [t,s] = strtok(s);
  else
    [t,s] = strtok(s,delim);
  end
  l = {l{:}, t};
end
